
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
SWIFT module of the Python FinTech package.

This module defines functions to parse SWIFT messages.
"""

__all__ = ['parse_mt940', 'SWIFTParserError']

def parse_mt940(data):
    """
    Parses a SWIFT message of type MT940 or MT942.

    It returns a list of bank account statements which are represented
    as usual dictionaries. Also all SEPA fields are extracted. All
    values are converted to unicode strings.

    A dictionary has the following structure:

    - order_reference: string (Auftragssreferenz)
    - reference: string or ``None`` (Bezugsreferenz)
    - bankcode: string (Bankleitzahl)
    - account: string (Kontonummer)
    - number: string (Auszugsnummer)
    - balance_open: dict (Anfangssaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_close: dict (Endsaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_booked: dict or ``None`` (Valutensaldo gebucht)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_noted: dict or ``None`` (Valutensaldo vorgemerkt)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - sum_credits: dict or ``None`` (Summe Gutschriften / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - sum_debits: dict or ``None`` (Summe Belastungen / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - transactions: list of dictionaries (Auszugsposten)
        - description: string or ``None`` (Beschreibung)
        - valuta: date (Wertstellungsdatum)
        - date: date or ``None`` (Buchungsdatum)
        - amount: Decimal (Betrag)
        - reversal: bool (Rückbuchung)
        - booking_key: string (Buchungsschlüssel)
        - booking_text: string or ``None`` (Buchungstext)
        - reference: string (Kundenreferenz)
        - bank_reference: string or ``None`` (Bankreferenz)
        - gvcode: string (Geschäftsvorfallcode)
        - primanota: string or ``None`` (Primanoten-Nr.)
        - bankcode: string or ``None`` (Bankleitzahl)
        - account: string or ``None`` (Kontonummer)
        - iban: string or ``None`` (IBAN)
        - amount_original: dict or ``None`` (Originalbetrag in Fremdwährung)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - charges: dict or ``None`` (Gebühren)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - textkey: int or ``None`` (Textschlüssel)
        - name: list of strings (Name)
        - purpose: list of strings (Verwendungszweck)
        - sepa: dictionary of SEPA fields
        - [nn]: Unknown structured fields are added with their numeric ids.

    :param data: The SWIFT message.
    :returns: A list of dictionaries.
    """
    ...


class SWIFTParserError(Exception):
    """SWIFT parser returned an error."""
    ...



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00@\x00\x00\x00s*\x00\x00\x00z\x04e\x00\x01\x00W\x00n\x07\x01\x00\x01\x00\x01\x00e\x01d\x00\x83\x01\x82\x01e\x00e\x02e\x03d\x01d\x02'
        b'\x83\x04\x01\x00d\x03S\x00)\x04z\x1afintech package not loadeds\xd2.\x00\x00PYARMOR\x00\x00\x03\n\x00o\r\r\n\t4\xe0\x02\x00'
        b'\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00\x92.\x00\x00\x00\x00\x00\x00\xc6\xbf\x08\x17H\x04\t\xcd\xd4\ttj!\x15\x8d\x82\x00\x00\x00\x00\x00\x00\x00\x00\x19\xfc\xe5\xc6c\x91\x87O\xef\x11\x0ck\x8c\xb7\x9e\xc5ke\x0b:\x1a'
        b"~\x00c\xf9'\xd5\x177:\xcemT\xe5\x8bs\x10x\x89\xa9\x8ewg\xa5\x19)\x89\xb8\x8d\xed\r\xfazH\xc1\xb2i\x99`c\xd9M\xf7\xb2\xe3\xba\xb6\xd4\x17h\x0b.>\xd6lj\xba}\xb7\x82S>\xc4\xc2\x96"
        b'1$\x16\xe5\x99z\x13\x89\xa1\x9fm\xdb\x8d/\xd0\x91\x1d5m,\xcd\x86\xf4\xc0\xfc<\x04\x00\xba\x94\x0e[/\xbc,:or)\x14\xab\xac\x15+\xfej\xf0\xc8\x1c\x0f\xb9\xd1\x13IBq\xa1\xf7\x16\x9b\x1eP\xd2['
        b"1\xa33\xf1v\xd6&\xda\x03d\xb0#\x86Z*\xbe\xcb\xe0\xf8\x15zex\xcd\xd1I\xe5{\x83\xff3\xd6\xc91\x85\x90\x06,\n\x11\xc6]c\xca\xf3P\x1a-\xe8d\xfa{&\xb4\xe6\xadq\x9a\xf3K'\xa9\xa5>"
        b'\xf6\xc6\xa1\x0c\x04\xde|p\xc6@\xd0\xea\xabAvy\x08\xae\x81\xf1w\xf6-1>\x10\xfe`\x81S9\x85\nd\xd2=\x02\xc1\xfb\x14\x1d\xe9\x1a\x8a\x19\x9a\x99M\x08\xc0\xbb\x7f~\xd2\xcb\xab H/\x81\xcd\x05\xb8\x89'
        b'\xb0\xc7\x827!\x16:\xc8&\x1b\xbb\xde\x07L\xf1x\x81\x03\xc3?\x89\xbao\xc4\x8c\xaa\xa9\xfb\xd8\xc1\x82\xd8\xe1T \xc41\xa3)\x1bE\tq\xfb\xc7\xbff\x8a\x0c\xe4$Q\x82\x14a\x1a\xc4\x11P-\xf9$\x1e\xbe'
        b'\xeaV\xbd\xfc\xe3\xf9^\xb3t\xf7zJ\xe2\xa2?\xc4Z\x14\x03WXY\xdf\xbb4\x8fFo\xe8]\x1e\xf0\xd0\xceP\xe4\x9d@\xe4\x0b@\xe0t\x90\xcb\xff\xe1\xd6\xc3\xd4\xf8\xdff\x9bG\xaam\xee.\x03\xf9\xcd\xa8\x8d'
        b'\x1a\xb6\xa7,\xca~\x9e\'1_;\xad\xb8\xabhDW\x9c}"r3\xc0&\xbe\xd7\x95~2\x80\x8e\x1cP\xdf\xaa\x93\xa2\xaf%\x05\xec\xca\xefV\xb1E\xc5\xc4\xfa\xfc\xd9\x99\xae\x95\x87\x82Y\'H\xc70\x10\x06\xf5'
        b'\xe2V\x8b\x11\x8c!\xa3\x1a\xec\xbf\xc0\x0b\x946\t\xf4\x9f\x87\xce\xbdt&\xaa\xbd!\xba9\xe9\xd0\xa9\xd1\x0f\x9e\xabV\x93\x14\xd9E\xe9\x88\x93VA\xe5\xded\xfd\xf7\xae\xc3\xd5\xa1\x10\x90A\xf0\xed\xac;\xff;\x08C'
        b'# \xef\x1a;\n\x02\x9a@-\x94\xab\xdb\xc8\x0b\xa3\xaf\x00\xcb\xe6?\xa5\xcb\xde\xaav\xaa\x1d\x81(\x16BGK\x03\xfb+\xf0\x83\x84rj}aS\xb0\xdcT.\x06\x13\xc5Y\x0085v\xbf\xe7e\x1e\x17su'
        b'@P\x86*\xde-),\xc4\xb1h\x15.4\x9b+\xa8\x95nort/\x03\xe3\x8f\x8f\xc2\x95\xbb\xe1\xd4\x87\xac%1\xce~\xc06\x1a4\xc4j\x1a\xfc*\xd0W\x9e\xe6\xb7\x97\x1a\x93\xb0\xff\xab\t\xbdd\xd0\xec\x7f'
        b'=\xd4\xa3\xed+\xe8\x19\x92c\xa5\x1b\x8c\xb3\x91\x1f\x06XMJ\xd1\x1f6\x0c\xebP\x10\x0c\x91\xc6\xd5\x81,I\xd4\xdd,&\xc0\xfd\x90\x8f@\xbb\xdas\x9a8\xe8\xff\xce\x99or\xc2\x97R\xe6\xf1\xd5\xde*\xe3c*'
        b'\xc7\xd1\x94\xe9\x81FND=aD\x84Dj\xe7aXJQ/\xb0^\x81\xff-\xfe\x81u\xb8\xeb\x05,\xc8/\xa7\xb4\xbc\xef\x0e\xde\xb9\xac\x1f\x0eD\xf3\xc9\xbd\xd4\xff60\x87\xee\x82\xab\x11RRLz\x9f\xe7L'
        b'\xb6\x8d\n\xa7A\xd4y=\x189\x98\r5\xf9\xa9\xc6D\x90\xd7\xf1\x0e\xc7\xa6\x85G\x87\xf5Gx\x1d|%\xcf\xeef**\x01\xd0\x81\xac\x01\xd61t\x9cT\xe9q\r\xdb\x13\x93\xeb\x8cA\x17\xbf\x15\xa3\xc97G\xce'
        b'\xc3\xa3\x1bI\x8d\xc8\xc29\xa0\xc4\xba\r\xb6\xeca:*\xf9\xf6v\xdf\x8e:\xdcs\xee\xa0\x05\xa7+\xbd\x14o\xbd#.\xe9ClY%\xe5\x97kQ\xe5M\xdc\x07\x94~|\xf4\x9a\x97\xddk\xa4r\x89\xcc\xd2|7'
        b'\x9b\xb2\x80\xe3^\xbd\xc1v^ws\n\xc7>\xe4J\x85\xb8Js\xc605:Vb)\xd5X\n\xf9\xba\rh\xfeE\xe7\xb7\xca\xe3>\x05(\xf0\x17\xc3\x94\x16\xd2@\xa5;\x0f2\x82"PxD\xf8\xbb\x0c\xa7W'
        b'E\xf7\xe6\x8d\x93\xf1\xfa<?\x90\xd0\xa6\xd7\x1ah\xe0,\x11\x10Y\xa4\xe26];\xef\xaaY\x0e\x99E\xf6\x82\x98\x80\xbe\xdf(\x86\xd1\xa7\x1a\xbdVZ8\xaf\xd8|^\x89,\xf7\xc1\xc6\xbe.;u\xeb\x9fS\x94='
        b'\x93b\x0c\x81v\x81\xe7\x072\xd4u\x9e\xc2\xa9\xdbP\xb9\xd8\xe8\xae\x84\x05X\xe7\x93n\xe5J\x16\x0e\xb9bNJ\x8fX@n\xb7:n u\x80\x83:\x97\xd6\xeb\x1fS\xf1\xec\x12.\x7f~\x9d]\x825\xe30p'
        b'P\xc2\xc2\x9c\xfc\x0e\xe17\xbe\x96\xfeE\x0et\x99\xebI\xd3\xd2A\xa1T:\xb9\x87\x95O\xcbp\xbb\x8f\xd6F]\xad\x8e\xe0\xf87\xb5k\x8f<G\x1a0(\xeb2X\x17\xa5\x91\x8d\xec\x91\xf6\x91D\xd0\xd6i)\xa8'
        b"\x85\xc5\xdd|F\x7f\x1dMF\xe9-\xc9\xa1}\x9f\xdb\xd8,\xf5\t \xb9\x89'Q3\x91\x07\xe2\xa3,\x18\x8d\x93\x80\xec\xd3\x1f\x18jx\xe9\x16\xdfm\x90\xb1\xd9\x12Gb\x1b\x8cR\x0b\xef\x95N\xb1\x858\xc2\xca\x0c"
        b"\xde\x9f-TX\r,\x91\x1a\x8e\xae\xf5\xbf\xaahg\x99\xe0\xd4]'Kl:g\xf0\xba}{\x83_u3\xa1\xa3\xb5`\xf8\xd8\x0b\x9fM*\x8a\xa5\xf4\xfc\xf8\xa0\xfe\xb0U0\xe4\xccYG\xd1\xe1\xc0\x1b\xdb\xcf\xb6"
        b'\xee\x083e\xf9\xfc\xd4\xc3\xb65\xe0\x0b\xf0\x90b\xb5\x15\xb7\x9e-\xd1R\xc16|\xa3\x91\xa4\xcc\xb7\xd0\xcei!7\xa2\x1dP\xec<\x89l\xb1\x0f\x01\xa9T\x1a\x83e\xf0\x91\x83\t\xa7@\xb9\x9f\xf2b\x99\xea\xe7\x8f'
        b'\x0e\xccn\xf1)B\x95\x8bK\xb4\x03\xc8\xb1\xb7\x88,9\x1dA\x92\x88\x19-\tY\x82C\xce\x976h;\xebw\x96=~\x87%\xd8\xf8\x99\xdf\xbe/\xcf\xe8z\x9a\xa7\nE\xe6\xf4\x8e\x99\xdd\xe3\xc6z\xd4[e\xb2'
        b"KJ\xd88\xbf6I\x11\xc1\x95)\x0e\x9e\xa5\xaf\xb7#Tr\x0e\x81-\xf7yo\xfc\xba'\xec2J\x15\xa4#\x10\xd9{\xd7\xd9\x06,\x8d\x8e@\xf9\x14\xb18y\nOd\xba$3\xd7J\x99\xdb\xd2\xa8\xdb\x05\xad"
        b'Y\x8f\xe9\xf6\x96\x08g\xe8\xb0z\xeec\xd1\x95\x7f"YL\xc7Te\xf8\x16W-\x18\xac\xf1\t\xeaX\x8dD\xf7\x19\xe31\x89\r$\xa6:\xdd\xe1\xfd]\x8f\\\xb2\x9e\xab\xe6(\xb6\xe7|/A\xe2W}\x9e\x99\x1d'
        b'\xbdm\xb9\x86G\xa8%\x14\xa8q(\xd7\x9a\xf4&\xb1n\x00%!\xfe\xbe\x82)D\xf6\r\x0e\x8a\xdd\xbe\x0f\xe8\x95\x9f \x05\xab\x8d\xe9\xcc8\x81\xec\xd21\x0b\x0f\xac\xc2\x949\xceV\xb1\x12N\xaa_\xc1L\xa2\x15\x98'
        b'\xbfOa\x986y\xbd\xde\xd4\xce\x92\x92\xaf\xcaG\xaf \xcaP\xe1\xdd!i\x88\xec\xb5\x82x\xcd\xe2\xe8\x1c\xb9b\xe2\xf9qC\x1bY\xfcG\xdc+\xacw\xbci\xfc\xafND\xec\xa7\xdf\x17F\xfbx\xb8\xda\x08!\xb0'
        b'{\xd2\xb7I\xeaU\xe9\xb1\x0f\x14\xd0\x80,\xb1\xf5N\x83\x9e!`\xba[\xa9\x0c+\xc9>G`\xa8n(\xb6\xd4{\xb6=\x96Hg\x85\x8a\xcc\xfe\nS\xec\xc7\x12\xc4\xa9\x1a\x8b`d\xaf\x12\x8f\xd26$D\xaf\xd9'
        b'Cc\xe14\x82\x11\xc0>PL\xe4R\xef\xddO~\xdbY\x10\xda\xaaM\x8d\x00n@\x1d\x90\x84\x05\xf3\x01w\x92W\x80p\xc0V\x04\xd7vmV\xb6hU\xad\x0c\x96<;bg\xa8\xb4kk\x89J\xc5\xeb\xd2\xc6'
        b'\x02\xd2z\xaf\xbc\xfdTa\x96\xda\x92s>\xe5\xafAZ\xa3<\xdb\x06\x96X\xe0\xc9N\x15\xb6\xc1\xfd\xb9\x8e\xe1L\xc1\x86\xee\xd7\xf9\x99|n\xf2J \x0b\x05\x04\x12\x0eF\xe6]\x99_Eo\x0b\x00\x8d\x155\x06\x14'
        b'`4\x9b`\xe7Q\xf8|W\xf6\xbb\xa8\xa3 q3v/\xac\x99;\xfb\x80\xbaJI\xb0a\xb3\xf1\xe0\xd1\xf8`\xa2\xe0\xae\xfd\xc2Y\x14\xc3\x1f\xf8\x82\x024~\xff,\xaf4\x01\xce\xd3h\xdb\x9c\xfc\xad\xd6\xd7y&'
        b'\x97\xaf^d\xf2\x1d\x9ar\xfco\x83\x01\xd2\xe8\x9a}\xb3\x19X\x15\xe6\xd6\xaeS\xfb\xde\x92\xe0\xb3~w\x12\xbf\t\xac\xb1\x17\x08MlAq\xfd\xdav\xb8G\xdb\xbb\xd0P\xfe\xaf\xbf.=)l2\xa537bR'
        b'R\x06\xc2\x11\x00\t\xd5\x05\xcc\xf8R\x0c3\xf0\xe5Cn9\xf4J\x89\x97\x11\x05X^\xa8\xc3\xb9\xbe\xcc8\x02\x8ci)\xb0\xe8\xad\xc8\xdf^\xd5G\x12\x1e\xca1\x1d1\x97\x0f\xa2\xb6v\x1a\x01\xa4\x0e0%\xf6\xcb\x85'
        b'\x93\xa1\x83\x8a8pY8O\xde\xa7=\x1c\x9e|&\x14%\x88\xfc\xd6;U\xafq\xf4M\x9aN\x7f\x0b\xb4\xd3i;\x8b\xdc\x01u\rI:\t\x9c\xed\xa9\x0f\xa6,\xae13S\x90\xb3\x90\xf1b$\x93\xa6LDO'
        b'\xf2,\x06Nd\xc6W\xdec\xae\x8a\xd9\rOe\xb6Wat<E3\xd3\x05\x0b\xe0%\xbdK0\x92-K^A\xb93F\x04\xd1\xbe\xccJ\x8a\xd2t\xd3\x98\xcbE\xe5\xe4e\xebI\xfe\xfe\x8b\xb6\t\xfaQkJ'
        b"\xb3\xdd-X\xa4u\x1f\xb8'\xb1\x99\xc2dW-+\x82\xb8\x89\xc1i\xf0\x1b~\xf5s\xe2G\x07\xec\xbe\xa8\xa1\xb3\xefs\x83\x8a+\x8a\x04\xa5D\xa2\x05_i\x97\xc5\x84q\xf68\xe4\x03=[\x1c\xaeqp\xcc\xb3F"
        b'9\xf9q\xd3\xd8\xc4\xb9v<h\xf5W\xeb}\x0f2\x94\x02\xdf\xb4%\xe8\x0b\x82\x07\xd9\x10\xc4\x03|M\x14|\xadl\x9b\x8e\x9c5\xd89qcUK\xb3w\xfc\xacaZ\x0f\x98,7us\x80d\x89`\x86 \xe2'
        b'\x8f\xfa3BdO\xb01\x1a\xc0q\xa1\xaf\xb8g|N\xe9C\xb5\xd1\xdd\xc9!>\xa1\x94EN\xad\xa0d\x05\xef\xbb\xd1\x92*\x08\xfd\xf3-k\x89\xfel\x86u\xbe\x0c0\xc91\rd\xf12\xe0\xed\x82(y*0'
        b'\x93\xfb\xb2+\xc1\xa6K\x90\xbb\x89\xd9\xc8\x9fH\x19=S!$Z:[\xf0\xc5?-3$\\\xcd`\xe4+\xc1\xbc{\x13\x87*\x86\xdd\xe6h\x88\x1a:\xce\xc7(\x862vx\xaa\xb2wXG<\x8a\xc8\xb0X\xec'
        b'g\xab1bj\x89\xe3\xdbp\x9c\xa8\xbe\x0f\xd1\x85\xa8\xd2\x92TlH\xa7_\x15\xc53\xb2\x1b\xe2\x8e\x86\x9e\xf1\xb5Y\xcc\xf8\x1e\xf8X]\xd8\x99$\xd3<\xd0\xf3D\xd5\xac\x18K\xec\x89\xa7\xdeeW;<6\x92['
        b'9{\xf8\x01\xcb\xedC\xe7Ym\x0f\xf2\x84t~\xdf\xf21[\x91k\xd6QV\xdb\x04V\x0c\xe2m\x9c\xea\x15\x8aw\xcd\x00\xd8\xeb8\xb7{\xfe\xb9\x9a\x0e\xf1*p\xd9\xa9e\x80\xc1K|\x9f\xda9Mn\xfbmu'
        b"\xf6\xb9P\xe9\xb2`\xad\xb3\\1^\x1b'L\x9a\xf9KH\x07\xb2\r\xab\xea%\xaa\xddi\xff\xe8I\xafL^R\xab<\xeaM\x15$\xa5k\x7f\x16k\xd4D>\xe0\xb5\x91\xad\x8bD\x08\xb2\xbb\xb0@\xd0O\x96\x0b\xf0"
        b'\xb3\x8d\xfb\xd0\x06PV\x93Cv1\x07/|\xbe\x83\x94\x18\xf7\x8a\xa6\xa7^}\xb905e\xf2\xdb\x9f\x9d\x9f\xc9\xf7\x07M\x06t\x9a$u>\x14\xd0I\x00D\xdb\xcb<\xba\x7f1\x82\xe9,\xd1fm\xab\xa0\x03\x15'
        b'\x88\xb6Iy\x90\xc4ke\xe7\xd3\xf7\xf4\xb3E\xa5\x150\xfe\x813i\xf6\xfd\xe4\xbd)\xfc\\\x11\xe4\xb9\xe9%\xbaS\xd6\x1a\xaf\x10\xf3;f\x88\x17o\x10\x11\xb0d\x8bR\xe1\xc8\xd0\x1d\xe4G\xfdp\xe9.\x13\xb5$'
        b"(\x9eV\x92$!\x93\xf5\xa1s_\xd9\x8b1s\x04\xe9 \xdb\xf2_qn.'\xaa\x15\xf2\xce\xafg#?\x1f\xcf\xf1@'Q\xea\xd2GTK\xef\xab7\xb1\xff\n3c!hG\xb8qT\xfbI\xf7*\x02^"
        b'TT\xe84A\xf4\x9bs+\xfb\x1a\x0c\xb7|\xfdx\xd8\xa5\xba\xdc)\x00\x9e\xc7\tRb\xf1\xa0\x05\x99\\0\xde\xda\x02\xeb\xa9\xce\xce\xd1\xe4\xfetf\xc6\xbd\r\xc2Vr\x96\xd7h\x9a\xe8\x97\xe6\xf4\xf6\x8f\xc1\x01='
        b'\xfa]\xa9hP\xe3\x18\x96+b\xda\xbc\xcc+s\xc7&\xab\x89]\x9dT\xfe\x11\xf9\x1cA\xd9\x81\xcf\xfb\x1f\x1fh\x95\x0e>\xf9I^\x81\x12\xdaKd\xd7\x16\xceN\x0c\xc4\x82\xa0\x12\xea9C\xa7\xaf\x8cV\xb5J\xab'
        b'\xb7t?\xb0#\xb4\x04Ao\x1e\xba\xfa\xd4\xac]\xd2S\xe5\xde\xca\xd3\x97\xa8\xd5w\x1f\xe9;\x05\x13\x9eOPVY\x19O\xb3\xf6\x8b\xa4c\x0b\x14\xf5\x0e6\x18\xc5\x99\x8b\xd2\xbe*\x972\x17Z\xcfc\x8d\xf1\x07\xde'
        b'\x82Kj\x86@"e\x8a\x1c\xee\xbf\x83>\xb6G9\xc0\xae\xd7\xfbxt\xe3\x93\xb8\xbb\x0e\xe8)\x1b\xf8\xa6\xd8\xda\xf6\xdb\x02T\x0f\xbd\xd2\x14\x06\x0b\'GX@\x85\x91d=n\xcdAa;\xde\xa3\xbe*\xeeD='
        b',\x195\xd7\xf1\x14\xdd\x04\xc2\xb8\xbaC\xcc\x06\xf1\xb1\xa3\x92\xf7*\x87\xc9\xeb\xe7\x92R\x81>\x94%\x9c\x0f\xb2Q\x91\x97@\xb8l\x19c$ki\x8e\xc7SG\xb3-\x01\xae_\x87E\x98\xb8g\xb38\xe8\xb1\x99\x95'
        b'\xe5\x19\xe0\x93\xaaE\x99^\xd8\x9d"\n\xb9\xf9}a\x12 \xd5\xab\xc2\xba\r\xb9J\xed\x87\x9f\xcf(JW%J;\x17\xec\xc0\xccb\x98\xf7nL"F_\xa4\x1f\xb0\x1c\xe2N\t\xdd\xf7\x97\xdd\x05\xca\xf9u\xe7#'
        b"\xdd\x86p\xd2\xfcG1)\x06\xe1\xcb5;\xcfB\x951\xb5\xf2\xae\xed\xe2\x9d\xbb|\xb7!v\\\xb7\xba\xc7\xad?\\\xc9f\xda@\x88FV\xc8\x18n\xcd\x96M\xea\xa35\xc5\x05\xed\xfe9\xe6\x8bYj\xb0'\xe7k"
        b'\xe4@\xe27\xb0\xb9\xb7\xd4\xe9~\x95\\\xfe9\xe3\x04`1:\x19\x95\x0e\xfa\xe0-\xd0\x0b8x*\xca\x12\xee \x92\x18\xf0k^\xde\xf8\xb6\xf0\x19\xfe\x1dV\x92h\x10\xef\x15l\xd7Z\xcb|QY\x14[\xb7#f'
        b"VpYv\xf1\xc6\x98B\x95\x92r\xb2\x06'\xd1\xacr\rH\xeb\t\xca\xb5(mD\x87\xd6\x9f\xc3\xf6\xa8\xc4\xf5}0{.\xf3lR\xd92Z~N;,\x07\x87\xa3\xf7``\x05\x14\x06\xe3Ol? 7i"
        b'\xea\r\xbe\xd9\x07R\x91>\xda\xa8\xcf\x99#\x19\xf0Mg\xb6}^\x0f\xd2W\x86-x(\xfb\x9e\x82\x9am\xf7b\xe6\x0c\xb2\x8e\xe0{\x9e\t~\xd6\xd8m}\xaa\xdc\x138\xf8\xce\xd3\xf0\x1c\xb7\xbc\xae\xc0\x84\xeb\xce\x11'
        b'\t\x8c\xad\xdd\x01e\xfb\xa4\x8e\x1dU\x99\x9d\x10:\x1b)\x16\xb7cg\xdb>.\x93?\xc7\xf6\x06\xad\x07\xd9\x87\xd5\x96\xe2\xab\n\xe3\x8c\x86\xc9b\xb4^%\xca\xf8\x1fN\xd4\xa6[\x8cN\x04\xf5\x1bt^\xe5_i\xfa'
        b'Y\x8d|\xfa^\xd4\x87\xb5\x7f?\x92\x16\x15\xabf\xd2x\xf7.\xe5H\n\x920\xb7v\x9c\x98x_\xa9g\x98\x86\xb1\xb0\xf7\xc1\xa9\xa4\xe2\x18f\x00\x0e\xe8m6\xf8\x05\x91z-\xf7\xbd\xcc&\xa7\xab\xf6\x9f\xe5:)'
        b'\x15eV\x06\x9cW1u\xd2>\xc4\x02\x1adR\xbd\x81\xa4\xcc\xa6\x95C\x99\x1e9\x8d3\xf5<\x01\xa1\xb3\xce\xb4\x1d\xe1\x14\x03\x80\xc3yP\x97\xd4\xff\xf0m\x84@\xef4a\x0f!\x8a\x8c\x1b[\x92\xf5QI\xc8>'
        b'\xb4\xe5\xf9}\xb9\x95\x86\xac\xa22u\xacah\xf4\xdb_\xc3b\xef\xe7t)m\xd40\x95\xc6m^bp\xc4\xa8MlI\xdb\xea\x934\x13\xc5;\xbd\xdf\xab\xc1\x15_M\xb41<s\x15\xb9\x9cw\xc9\x10\xd0\xf4.'
        b'w\xe9\xb6\xaa\x9f\xfa=cE \xefN\x9af\xd7+\x94\xfa>\x1c0:\xd8\xee\xe9\xba\xd6\xeb\xf3\xbbX\x9b\x1e\xc6\x96\x88>\x86\xde=\xa8\x8c\x83n\xce\xe7\x9eX\x80\x1d#\x06\x83 ]\xd7\xba\xa3A\xb5/\xa2\x85\xea'
        b'\r\x80\xdcH\xdd-\xeb(\xcd\x9f\x01\x13n(S\x02\xf0\x9e\x8b:\x17q,oC\x1a\xd9u\xb8\xb7{\xa1_\xb5l\x95X\x85N\x924\xd5I\x8b2O\xa0\xe93\x93\x99\x82\xc30up\xdbMFo\xda\x9f\xa4o'
        b'p\xce$\xde\xc5\xa2H\xbc\xb2\xeb%\x10\x1a\xea\xa3n\xd4\x89\xbf7!^\xefOm\x937\xd8#H\x9cxo#\xa1\xe1\xc0\x1d\xc0A\x91\x83\xa7\xd9\xa1\x9b\xa9\x8f\x9di\x98\x1e?\nY\x1fZ\x01c\xe1\xf2W>\xf9'
        b'\x10\x12CAN\xaf\x7f\xbb\xf5\xef\xa2,\xe7E\xb6\x94\x13j\x88_=\x94\xad\x90\xea$\x90\xb1\xd1\xc0\x0b\xcc\xc3F\xba\xa2\xe0LZ\xc3\xfc\x0f\x15\x075\xda*dZ\xe6\x08\x07\xad\x8d\x11i\x8fH\xd4^j8\xa0\x92'
        b'P\xc1x\x10`,Ga\xa2\x84\xb6\xfc\x95\xbe\x14\x83\xf4\x16x\xd0\xf0.\xae\xfb\x08\x9b\xce\xbd\xb7s\xa1\xe5\xcaS]\x8c\xcfT%\x05\xb8Z\x86\x11\x0f\xcf\xb9\x0fC\x88\xa6\x1b\x1e\x95\xc5[\xf2\xb6\x10\x139\xf3f\xbb'
        b'\xf6=\x85X\xfdAV\xa92S\xf4vD\x19XE\xe8\xeaI\x93\xacA\xf0\xc1\x95\x14\xcc\xfc\x9fmUJ\xe6\xbb\x02\x89\x84\xa2h\xa3\xc9\xca\xad\x14\xc0:lG(+\xd6Q\xab\xdf5V\\xm\x0f\x1e\xbc\x00P'
        b'\xc9H\xfe\xa2\xb9et\xe68\x08\xe41O\x83\xc9C!\x81&\x16\xce \x04\xc2\xc2"x\\G\x08\xc2\xe7\xde\x08E\xee(\xcf\xce\xa0A\xc6\xde\xdey\x94\xed\x9b\xd3\x86\x9a)C\xd3\xa5\xf2[\xc6\x0f\x97\xf8\xbd}\x02'
        b'\xfe\x85-\x8e\xff\xe6\xad\x1d\xc2\x1d$\x15d\x85EO\xb6\x0f\xb77\xd0\xa5\xc7\xf2\xad\xdc\xc3IO\xb4\x17\xfd\xda5{!\x82\xb5cS\xad\x85\x86\x0cT4\xd6\x80+\xca*rz\xac\x13\xe3\xfc\x9b\xdb\xc5\xd8\x02\x1e\t'
        b'\\\x14\xa5\xf3*\xc1e&E\xe4\xb2z\xc8=\x99\x97(\x0b\xb8;SJ\xde\xcc\xc4z\xca\xa4\xa5XG\x13\xb6\x1cW=#5\xf29\x1fNw\xfc P\xdb\xb1\x8e\x83,X\xf5\xa0\xba\x91C\xfa\xd5oiT\xe13'
        b'_.\x07\x01J,\x95\x9e\xd2\xad_\xe3F\xee\x93\x1c\xa6\xbf\xf7\xc48.w\x9d\x8f\x98\x8a\x97\xab2\x9c\xa3w\xaal\xbb\xe7\x96\x82D\x92\x89%|\x025\xf8\xae\x8f\xc3\x8c\xa0\n\xcd\x89hvSh\x9f\x872\xf9o'
        b'\x87]\xfe\xc6\xf2P*\xc8\x12\xb1\xda!Y-\x17\xf262\xa5\xb14\x8d\t7\xa8\xfc\xcf\xbe\xa7\x88]\xc0\x9f_*+7\x80[\xd6\xe8.BH\xbb)\xad/\xc4\xa8\x8fwu&\x9b\xd7\xe6T\x86\xa1\x9e\x1b[\x01'
        b'\x07\xd7\xf3E\x1bN\x0f.\xe6\x0f%\x8d\x7f]\n\xee\xc0\x87\x03 a\x8c\x7fO\xd2\x04\xd6X\xde\xb3te\x92\xad\x90\x1a\x16a\x9d2~\xb7\x84\xae\n|\xef\xea\x14\xdc\x1c\xb6]p\xb8\x03h\xb3.A\t\x02\xd6\xb5'
        b"\\\xe5^\xfe\xea6\xe0T\x88\x07QH\x19\xd4\xde\x96\xe9\x1d\x98\xfb\xd4\x1d\xee\xa8tg\x1e\xe99\xe4\xde\x9f\xdcPy\xb9\xac\x9c\xb2\xac\xe82B'b\x06\x9d\xca\xec\x00z\xb57B \xdfM\xaak\xcf\xb4\xaaCM"
        b'=\x8f\xff\xe4\xf7\xe6#\xf0j9\xfe~\xde\xacuf\xd2\x03\xff\x1dvdp\xbb\x0b\xf28\x80\xb4\x8c\xb2\x01\x87\x00|R\xcc\x83\xad4\xcb \xf3\xef[\x98\xb6$(\xaa\xa2[\xfd\xc7\x81\x8av\xb2\xa9\xd4\xca#\xe7\xd2'
        b'\x93;\xe1\x0f*\x11\x81\xe9\xe9\x17\x95\xbf\xaf:b_\xecK\x01&\xe3\xa5\xd2-\x0fs\xeb\x9fW\xda)_\xa9\x9di\xf1p\xe8\xf9\xf2\xda\xf5\x07\x00\xa9\xeb\xa9\x87S[s\xc4\x85\x94\x0f\xd4\xb1\xbd\x1fT\xa1C\x91\xe4'
        b'\xb5\xfb\xef\xef\xc5\xf9\xbe;m\xa0\x87\n\xa7\xf7}5enY.\xad\xc2\xb3\xa5\x85Z\x04\xfajl1\x94wm\xfd\xee\xdd4f\xc4x\xaa84\xa9\xb6\xd9J\x18T\x99b\x81\x128t9\xe4\xa0\xdd\x8f]k\xa4'
        b'\xd2}5\x03j\x15\x9d5t\x99ocKK\xc4\xd5\xeaG\x1d\x93\xd1j\xd6[Qd\xd8\xe5\xdd\xa3\xa5\x9f\xf1\x13h@\x18\xfc\xb8-\x8f{t\x82\x0f\x11\xd9 \xab\xe2\xabW\x920 \x17U\xf3\x18\x9d\xef\x9c\xa7O'
        b'\x16U_\x18\x10\rI\x7f#o\xed\x8a\xf3lSH \xc0\x19k\x7fw0\xc9\xdfJO@)\xb7\xf5\xf1%\x1ddm!\xc0\xa3J\x06A\xa1&gO\xfb\xe8p\xe1\xca\x8c\xef\x15@\x04\xc6y\x11\xbd\x81<\xa7\xe6'
        b'I\xeb\x97{5\x949\xea\xfb:\x90\x1d\x8d\'\xa2)\'\xfe3\xcc\x96\xa6`&\x15\xea\x8f\x83\xa0\xd2\\\x8a\x96\x9cgU"\x97\x1a\xaf\xear\x04\xe1\xb3\x04\xaf\xb1\xfc\xd3\x07\xadU\x9dA\xf8l\xce\x11\x07\xc5\x14^\xb7'
        b'Bd\xaf dh\x8b\x1f<?K\x8bh\x1a\x12\x96\x90A\x90\xd2\xeb\x1by\xb6\xf4\\B\x15^\xf1\x94\x11,rJ\xaf\xb0\xb6gm\x9b\x89\xbcw\x99c\xd4\xc7\xaa2>>\xc4\xb4e\x95[\xf6\xa7\\Y\xff\xcf\xef'
        b'\x90qnK\xfeVE\xf57\xbb\xf0\xf7)\xeb\xf2F\x86\x11=\xed[_\xcf\xbe\x11\xce`)C\xbd\xca\xad\xc6x\xd6_4\xb4\xd6F\xdb\n\xe1\xfb\xcb\xd2\'j\x9f\xd4}\x1d\xd9s\xeb2\xad6"\xb2T|\xba\xd3'
        b'}\xaf\x95\xb9\xfa.\xb7\xe9E\x0f\xec\xe5\xf9LO\xba\x9a\n\x15x\xa4/\xb3\xe2\x95\x07\xcd\x92::\xe9\xebL\xa9\x95_\xef\x1e\xe7L&\x18\x07!\xf1\xa8\xde\x1d\xd7\xa9\x11d\xec\xdc\x07v/\x1fS\x12\xc3\xe1n\x81'
        b"{\xf4\xc5\xdc\x9e\xff\x03-\xa5Q7\xe3b\x1f.\x04\xb5\x8a\x17G\x93\x17hSc\x02>j?\xcelj'%\xb2.:S\x00|\xe8\xc9\xe9\xb5\xf0\xe53\x9f6\x97\xf34\x12\xd9\xc3J\xf7\xe4A\x80\xed\xb8\x15\x07"
        b'B\xb1)\xed\xb3\xc4;\xf1\x8f\xaf\xe1\xdf\x9d\x8d\x14o\x1f\x0e[\xc2\xac\xb2\xe4\xa7\xd1\xf1\x18\xc7\xdd\xd5\x8c\x0b\xb7\xb8\xc1\xec\xfdo\xfb\x98\xf0\x90W\xf7\xe4\xd7\x10|\xce1.g\x93\x83B\x82\xfaP\x8a\x84\t\xb0\xb8\x9e'
        b'a|\x9b-\xf9X\xc1\x031\xdc\xf5\x1bvt\x81\x10\xa7+~\x85\x8c\x02\xa2\xf6\xf3\x04\xf5\xf4\xb5\xe1\xa5\x17\xfd\xeb}u\x81\xd1\xd4y:\xd4\x02\xae#\xe7[\xe0q9b\x88\x0bGb\x96\x03\x01%\xdb\x06\xd2\x0eD'
        b'\x9d\x1fP%\x0e\x9ek4\xc1\x8c\xbb\xa6z\x91\xf3\x05\x18\xf2Q\xa1M\x1er\xacqmZ\xf1\xdc\n\xe9\xb0w\xd1R\x82\x14\xc6\x12}\x00,\xf9\x9a\x8b\x14\xa9\xc6e\xa7l-\xa6\x03V\x9e{\x81C\xdf\xcdw\x0f\x18'
        b'A"\xca\xe2b:\x94\xc6\xf2\x91\x9d\xe7y\x9b\xc6\xc3\xf5\xbc\x1a\x1e\xa6\xdc\'_\x00\xe4\xf1\xaf\xc7g\x05\xbep\r\x8ac\xd5ld\n\x8d\xe6!\x0fF\x94\xbfS\xc6\x8b\xb5\xb9\x0f^\xd1\xc7&\xc5\xd0|g\xe3\xb0\xd5'
        b'\xb2"\xba\x13A\xd8(\xbcgh\x9c\x04\xcc\xeb6\xe5mS\xa5\x89"\xcd\x13\xde\x8d\xed\xe04;\x03\x96\x1b\x83\xfc\x01\xec\xc2\x80\xb4\x8c\xf3\x7fbe3\xd2\xa4x\xa3\x9f\x98j\xf5\x1f\x97\x91a\xb6gx\x8e\x9d\xa3\xdc'
        b'\xb9\xe2\xa1\xb8\xf0\x807\x8b!Z\xe0\xef\xda`\x9a?\xbb\x8d\xcb<\x98\xf3\xf6G\x0e\xce\'x2\xcb\xd6\x90+.\xc4\xe7\xc6\x82tE\x06\xce\x12\x95\xaa\xd8g\xe9\xa5\xa9bW\xb1]\xe5\x14\xa9$\xdd"\xc7\xb3\xf8i'
        b'\xe7\xc7V`\xe8F\x0c\xc4\x88T\xbc>\x0f\x19\xeb]\xda\xd6\xb2\xf7m\xfe\xd2\x80.\xaeI\xda\x96\x02-\x9b\xd9\xcb\x86s\x150\x14\x13\xdb\xb9\x9a\xa4\x02\x88s\xb8\xf0z\x8b\xab\xbc\x8c+~\xf7\x81K\xc9\xe9mQ\xb3'
        b'rUk\xba\x8c\xb6*\x98\xd3\x08\\B\xe5\x90\x88\xeb\xac\xdc\xdc[\xe3\x93\xbc\xbe\x87\x94p\xb3\x1bi\xe9c\xf9AT\x87Q\x99\x14|N3\xec\xd4\xce^\xc8l%\x180{Bs\x95$\xff@\x086\xb1]\x9e\x14'
        b'YS\xc2`\xfeh\x81,h\xab\xbc\xdcm>\x18=\x84\x1aJ\xc3\x0f\x8c\x92HI\x11\r[dN\x02\xc1\xcc\xce\xc2\x16<\xc3\x16\x88\x92\xec\x1e\x9cyL\xe0\x01\x06r\xe4&\xec\x91\x93\x95\xed\xd6=~\x93\xdc\xbc\x84'
        b'\xb5\xc9\x7f?\xc3\xaf^\xaa\xe8a"A\xcc\xbfS\xad!k\x849\x8c$\xf2\x15\xc8\xe8\x8f\x92pL\xdc\xc4\xee\xd3,\xe92\x06\xcfjt`\xd4C\x93\xb3\xe4"\xee\xa1\xc8\xac\xe2\xdb\x1a>3%\x91\x8b\xc6\\\xa4\xaf'
        b"b3\xe3?\xc8\xb0^\xf3\xe5\x92V\xc8\xcb\xe5u?\xd1\x94\xf1 \x04\xb1\xd3 \xcf\xc7a\xa3\x91\xc2C\xf9RvP\xe2\x12\xc2\x82\xfa\xfb\xe9\xa1\x8c\xf9y\xfe\xb6\xcb!\x9e\xc9\xb9\x06'ay'\x19\\5\x02\xaa\x02"
        b'\x83\xe0g\xca\xf7\xaa\xf7\xe6\x1adE\x00\xd0\x13\xc0\x0b\t\x81\x11Z\x8b\x93\xbb\xa0NR\xd4\t\xf3;|B\xd8\xe82\xe0Y\xfdzZ\xc4E\xde\x01\rd\xd9F\xd71\r\x14llI\xb0\xcf\xae\x19\xfc]\x96\xe9y'
        b'\x14\x1b\xb1\xf9\x84\x08wk\xff\xbeq\xc2\xcd\xe5\xabm\xd3\xc8\x98L\x7f"\xdf\xdb\x04\xdc\x13\xd9\x0f\xe3\xebZaS+C\xf5\x00}\x9b\x8b#I\xcaX"\x8a\xaf\xe0e\x89\xa3{MS\xd5(\xf8q\x11F~k\xd0'
        b'\x8e\xe6\xc9\xfb\xebZH\xfb\xa6iv\x8cx\x13\xee\xac\xab\xf2\xd5 \x81\xb49l\xdf\x83\x07W7a#\xb8\x1b|\xd5IXcb\x12nT\xe1\x90BBG\xaa\xcd!H<\xf2Al\x8f\xe3\x1c\x8d\xdf\x84=\xc5\xa5'
        b'\xe4P\xab\xbd/<=\xce9T\x8224\x16H\x03\x03\x08\xbd\xb7V\xfc\x1b\xd9\x85|\\D\xd5\xc1P1\x1d\xc0\x8c\x01\x0b\xf6\xc7\x85d\x06Ea\x02\xa4N\xf6S\x19\xa40sl \x88G\xee\n\xcda\x9c\x1f\x06'
        b"Fi\x1f\x08\x145&.\x0fCq\x13sp<\xf4\xc6\x0f\xbaL\xdcA\xaa\xa9\xbc'\xf0\x08_\xdb\xd4\x05z\xb5\xa6\xf2\xda\x8e\x02\xbc|!\xa5j8{\x94/l\x1e\xa6\x84\xb6*\r!\xc2\xa0\xa7B\xc2\xc9\xe5B"
        b'\xda\x90\x06\xed\xf86RP/2\xfa\x9f\x18\xbew\x9c\xa4\xd5\xba\xf6\xe9\xbb\xe3\xf6\xa87so\xcfr[\x9f\xbb&\x0e\xbdJa\xf0\x19\x9f\xaf\x19\xd7\x04k\xc9\x07J\xdf\x8c\x92\xbd\x10C\xb22\x16\x04\x0e\xb6\x95\x87\xbe'
        b'A\x1d\xe4\xfd\xd68#)\xb6 \x00W\x80Un\x8cW\xa1\xe8\xec\x01\xbc\x05@\xa9\x1e\xd3W\x1a+PE\xf3\xca\x9d\x87]\xffz\xd4*\xba\x05\xf7]\x82\xac\x19\xde\xb5\x8fo}\x1c\xab\xbfdJ#m\xbe\xea\xc4\x9c'
        b"|T'\xda\x1a\x99\xd4\xaf\xf4\xbc\xe3\xf1,|Y\x130N\xfe\xcf\xb5G\x1f\xfc\xc4\xf7u\xb3\xdeN\xc0\xfe+\x7f+\xbc[f+vpBCH\xa3\xa3\xd9\x89\xa9g\xfb\xb5\x1d\xd0\xe8^\xfd\x8f\xac\xf2\x07/\x96<"
        b'\xac\x9ex\x87o\xf30\xac\xc3\x7f\xe5\xdc\xa9?\xd0I\xc7\x86Q\x1fsU\x0b\x8c:\xa7\xbd\x9a\xb4g\xd2\x18\x03\xf6:\xff\xf5d\xdd\xe4\xe0z(\xf1?\xcf[5\x81M\xe9\x17E\x1d\xc4\x93\xf38\x17\xb2z*\xe2\xb3'
        b':\xab\xb1\x07\xb4\x84@6\xdbE\x97\xac\xb5\xa0x\xb1\xe5C\xe6\xfd?/\xf0K6\x9f(\x84\x05\x82\x82\x92\x1d\xd9W\xb4S\xae.\xed\xad4\x1b\xc9D\x84\xa2\x12\xb0L\xc1~\xb8\x88<\x9e\xb9T\xf0o\xa3C\xcd\x9f'
        b'q\x87\x06\xdf\x1f\xf5\x1b9\xf6\x7f(g:6p%|\x1a\xe7\x81\x0cv\xff\xfc\x91\xede\xa6\xbb\x15\x83\xcc\x98\xd9v\x0c\xf1\x9eOC\xc1#]=Onu\x13\xe4 ]z\x12\xf1\x9d\xd5\x1b\xf34n\xf8.\x083'
        b"\xee']\xcfg\xc4\xd7C\x93\x9bS+d\x18\xf0\x0e`\x00K -.\xfd\x16N\x97\x86\x1ca\xb1!\xb9}?\xad\xd9\x86\xd2\x94\xd46\x07J\xd1@\xca_\xdc\x0c\xa5\x9e\r\xb7\xaa\xab\xaa7\xde\xd5\xf9y\xe6\x9a`"
        b'\xb3\xc4@Yf\xa6\xf2\xec\xd7q\xba\xa8V\x18\xbe:0\x04\x04\xeam\x95\x0f]\xc8.M\x1dF\t\x85}\xbf(!1\x83b?\x19|\xbf\x87^\\\xf0\x9e\x1e*\xe3\x8cCZ\xe9\x89\xbb\xa8</\x11|\xaf\xbb\xa2'
        b'\xe2\xb6\x0b4,1x\x89\x10\xa2~\x8c\nw\xdc#\xd9\xc3#1\x08\xfd\xd6\xb1\xb2\xc8\t\xb7.\xd7\xabq\r/\x8c|\xb5\xdb*\xd04j\x85\xf6\xac\x02 \\\xb00V\x17\x0c\x89N\xfa\x00\xb1\xb58\x8e\xf2w\xa6'
        b"\xab\xb8\xf0^R\x15\xb6\x06\xd3\xd3\xfe\xeb\x92\xc5\x88\xc8'z~$)\x9c\xda!Q\xee\x06\xdb\x83\xa5F'\x0c\r\xfdI_o_AC\x84\xfbj5\x11}\\3D\xd1\x08\x92\x89\xf3\xf9%(bRxTN@"
        b',\xa9\x88\xe0j8\xe1\xf5J\xdf\xe2\\\x08\xbd\xe4\xa6\xb3\xf7(\xc4\xce\xde\x05A\xd8\x08\xf2\x00\x8c\xb8Gp\xe1\xf6JK<\xe0\xa3#\x870\xde\x89B\xe1\xd9\xe4\xd4T\xba\xd5\xbd\xb5\\\xad\xfeN\x89\xd9\xa1\\\xef\xbf'
        b'\xc5\xd00\xb2\xa5\x1bignzj\xa8\x12\x96\xe4zh\x18e\x86HZ##\x00\xba\r\x8c\xa9=\t\xa9\x11\xa7\xeb\xea\xbe\x89\xc6\xeb\x87hXq\xfa\xb7F\xe1a\xc6K\xb5\x9aj\xeeq\x15\x0bM\x93qX\x84\xfe'
        b'\xad\x01\x17A1b\x87\x83#\x06\x0b\xa4\xa7\x9d\xfe\x19\x18"\x0bd\x9c\xc3\xacY?\x96\xb9\xff\x03\xf5w\xbc\x1a\x8f\xd8V\xe8\x83+\x98\xb9T\x945fq.{\xd5U\xcd\xa9\xe2\x83>C\xffygJ\xa3O\x98D'
        b'\xbcW\xdf3g\n\xe0\xd2\xea\x1a3\x8b\xe9\xb0\xe3\xbc\x89P\xa5\xd0\x8d\x87Q\x98\xee\x9b\x04\x0c\xdf\xef\xc1\xaa\xcd\xa1\xb1>\xaf\xb2o\r\xd9bY\x91!\x03\x802[)\xc1?\xf2>\xac\x9a3u\xdfkm\xbag\xc4'
        b's\xe3j\xa40HY\xb5\xd1U\x089\xf4<\x9d\x9a\x8c\xf9*\xc0\xe5V\x9c\xdfb\x16\xa9\xfd\x8b\xd8<\x1e8\xd5J\x8e\xbe\xa7h\x91I\xc9<\x15H"\x12q\x86\x8fk\xd1^\xb0\xbb\xe2j]F\xbc\xa5e\x9e\xd0'
        b'5\xab\x04\xda\xb5\x87Dll\xb7\xb4N\x91\xee\xfct\x9a\xd1\x0c\xfd\x9eM%L\xbfU\xd1\xd3\xa8\xff\xb1$-\xf3\xbf\xb7\x88\x17[]o\x7f\xec\xfe\xaeR}\x00XU\xf7\xea\x18\xca\x85)|/C>{\xec>\xf1'
        b'\xeb\xf6\x8a\xf8!Q\x8c:\xbeP\xd2\xce\x01\xc4\'L\xdb|zE\xb5s\xcc\x10\xaeT\xfb\xf8\xf8o\t\xb8\xdb\xa3\xf56\xab\xca\xf5\'\xe3\x9a\xa9\xd1\x8f"\xf9K\x10\x8fu9L\x87:j\xdb\xda^\x03\xeb.z\xf0'
        b'\x14%C\x8e#\xb5\xe0u"\xc3\xda\x01z~\xb6\x8b\xe5\xbc\x816\xecS\x0b\xd3\xcewO\x98\x85\xfbOd\xb1&5\xb5\x7f.XB\xd6\x9b\xfaw\xbbv\xd5T\x7f\x91\xa3M02DS,\xec\xb5\xc2j\x07\xdf\x8e'
        b'\xa88\x9e\xb1\xe5\xd5mgQ\xdfFdb\x15\x03l\x88\xf9\x04\xc1\xfb\x0bO\xb7\xd6\x99/pbEe2-wq\xa0\x1c3\x7f\x88\xc5\x11_&e"\xe2~\xb4\xb2A\xbaU\xc9rF\xbb\xa1\x80~i`\xc2\x07'
        b'\xd9\xae\xa0Zag2\x08\xdc]\xfe\xd5xS\x109[^\x0b].\xa2\xd2\x90\xfd\xf8+\xf46\xa5\xe9\xbd\x9c\x82}@\x1b\xd5\x9b\x03.\xf1\xc5\xe9\x91\xc9\xb7R\xd5\xf4\xb5\t\xf4\xa8\xb9z\x00g:\x1e/PSJ'
        b"\x81\x16\xdb\x97\x90|\xf0\xae\x12\x9b\xc4[\xda\xad[fM\xb8\xde\x15\xb2\xb4\xc8\xb5\xf1IN\x07\xf9i\x86\x99\x16r\xffn\rr_\xdd\x11\xd8\xd7\x98\xec,'n\x17_\xdeg\x1bm\xd8\xf8\xcc\xa2\xc4\x90\xb9\xd0\xcd1"
        b'-V\x813\xe9\x0c/gL-\x97aL\xd7\xa2\xb3\x9f?-\x0e\xdf\xb0\xb7T\xe3_C9]6%=J\xecn\xd1\x05V=!\xad?\x9e\x1ek\xcdw\xea\x0ff\x8b%\x9a\x0c*\xc7\xcd\x9d\xb1\x9a\x02>\xd3\x19'
        b"\x92\xd4\xbc(\xb5\xa0\x9bqo\x9ef\xdd\xd9\x90\x7f!\xbe\x9f\xb8g\x9a\xfb\xc8\xfd\xbb\x13\xca\xfcq\x8f\xa3'\xd9y%\x039\x9b\xb2\xca\xb4\xc0\xfe\xed%b\xbe\x1e4\xfd\x1bv \xef\xfcC\xa2nJ1B\x9a\xf6\x06"
        b"5\x0f?O\x1f\xe89\x07\x0c\xad\x06u\xa0\xc8S\xb4m\tS;\x0cm\x0f\xb3\x16\xa8\x9b'f\x16k6va\xbb\x84@^\xb0?`\xc5\xa6\xf0\x98V!\xc4\x03\xb7\xfb\xfe\x86\x85\x1d\x0f&\xa9\xd5\xcbR\x92 \xb2"
        b"\xc9\x9bT%\t\xda)\x9a\xc7\xd1\xde'k\nC\x94\xf5\x90\xe5\n\xa1\xb8\x89\xd2\x8e \xf7@\x03\xd3th\x03\xec\xd8\xe8\x19\n\x00L@o\x93*\x82\xa7l\xc7\xe8\xb6\xf8\xf3\x8c\xf1%\xa2V\xb7\xe3\xb7\r\x8f\xd6\xc2"
        b'<)h*\xd4\xcbD\xe6\xbeeV\x1c+\xab\x94B\x00u\x01\xd3\xd1@\xb9\\}!L4>]\xbc\x13u\x08\xaf\xb5\xda\xebZEm\x14\x02\x89i\xa9\x05\xc5^\xf2\x05:\x85\xc3\x1e-\xdcW\xc6\x04\x99<\x93\xf0'
        b'\x83\x9bZ\xbc\xbd,~DQ\xc6\xfd\x87\xfa\xb1\xf7q\x15\x80\xc1\x18y&5\xe2~w\x95\xa1\xa0\x175\xf6\x10\xa7cS\xff/\xc4\xbd\xbe\xe4\x80\xb3IAT\x8aB\x97 \xd2"\xd9Z\x94x\x97\xfcq}\x14\xa4\xa4'
        b'_\xa3\xd6?\x8e\tl\x15\xf1\x1a\xeb*\xd8g"N\x95\xb4_\xda\x90@Z\xc3\x16\x0eH\xb5s\x0f\x18\xe9]R\x82\x11Q\xb3L\x90\xb65\x11\xeak\xac\x00\xdc\xfb\xb8\x93u\xa7Cv4\x1f\xda\xab\xf9h\xcfi\xe8'
        b'I\x9b\x97?DF\xd2j*\xffSIY\xca\xe3\xfau\x9cA\xb2\xa0\xf6+-\t\n\x18\xbd\xd9\x00\xd6\xacn94\xf3\xb5=\xdcv\x97\xac\xd1s\xc7H\x82\xd30\xc3j\x9f\x81"\x7fk\xc8\xf4}\xb8\xbf\xa4v^'
        b'\xd9-\xf3\xc7\xacuPs`\x1f^B\xf1]\x94iI\x11\x94\x88m\x19\x85\xea\xf7\x0f\xb73\xd8\xf0X\xbe$\x87h\x04\xd7bj_\xe3\x15V\xbf\xb1\xfb\x99\xd4\xc4Cc[p\x90--\xeb3y\xda\xee\tD\xa0'
        b'\xb4#(\xec`\x03}\x11\xcbs\x82|\xb24\xbc,\xc5\xc2\x80<\xa9@\xe9\x04s-\xfc\x8f\xa0y\x1e\xcbJp\xaa|04qO\xcf\xa9\xc3\x893\xea\xee\xa9\xda$g\x0b\xdf"\\x\xf9\xca\x84\x9bq0\xb5\xb0'
        b'\x90\xca7\x93\x90Y\xe5\xa7\xf6\xe1\xbd+\xf4q\x1b\xf4(5,5%\nGf`=uB$/<\xfc\xf1\xda\xd8\x16f>"t\xf2\xb1\x1b-\xa1{\x82j\xc8\xd5\x7f9\xfa\xcb\xf0}\t\xf2\xa6\xcf\xf3\x05(\xee'
        b'T\x8c\xc8r\xbeea\x9d\xb8\xab\xe9\xb5UM\x99\x8aB\xb2)\xc7\xa7\x9c\x8e\x86\xcb\x8a\xbfhV\xcd\xfa4\xae\x85\xe6\xb5\xf7\x89\x81O\xdd\xb89\xe9\xbdV0pX\xab\xb8KW\x98\xdcyf\xad\xfbxz\x00\xc5\x8b'
        b'\xd0\xb0\xf0\x92`\xd7\x13\x1a\xc4\x14\xe0g\x85;\xf0\xf5\xfc\xd6\xa54.F\xc7\xd9\xc4A\x16K\xf7V\x86]X*\x84t\xb1\x9fI\xafD\x1c\x07o\x10,\xb2\xc6\x00\x95e\x14\xc2_x>\xf2`\xa3\xe9c\x0f\xb7y'
        b"D\xc8\xfd&6\xc0\xf4\x11\x94\xd6\x0eH\xef\xd6\x94X\x07:i\xd5\x12'+{\x9bp\xd0\x04\xb9\x1cP\x06=\xd5\xc8=\xd9\t;\xe1\xf8\xf3\x8f6\xda\x02f\x16Y\x1fA\xa0\x91\xc2s\xb9s\x92\x9f\xe5h\x0c\xf1\xb0"
        b'l\x96\xb3\xbc\xcbiY\xf9\n`\xd7\xc1u\xb0@\xb4\x08?L\xd8xE\xdf\xa6Do52\xcc\xf9\x9f\xbcW\xde\x0e\xe7mi\xaa\x15,\x978\xb6\x86v\xae\xeb\xe3\xc5 \xee\xfcY8\x17RTt\x8e\xb9\x93K\xab'
        b"\xa6\xfbW\x88wG9a\xd3\nnQ\x9f\x96%\xd2'\xea *f\xbef\x1b\xc3\xf6\xb5nF\x82\xc2\x1d\xffA\xcd\xb4u\x8a\x17\xe6\xe4\x95\xe2\x88\x89\xe1\xf9\xc3\xc4e\xfda\xc2e\x81.\xd7\x9e\x82\xbd|\xe6+L"
        b'z\x946\x87jn\x16\xd9%eR\r\xa4S\x0bwv\xa4y\xf9\xc1\x1ad\xec\xc4\xe8QB\xfb\xfa\x96\xe0\x0f\x97\x11\x93B\x90\xb4\xa2\xd9S\xba\xca\x80\xc9\xe6P\x87a\x86\x8e~\xd1b\x02\xfe\xb1b\x99d\xa8y\xa6'
        b'\t\xe2\xa3N\xf5\xe6o\xbaY`\x19\xa3\xdb\x8e\xf7C\x04!\x1c\x0c\x9b\xdc\x9e\xf8OB\x0e\x95S\x83\xa8\x14\xda\x1f\x98\x9ej\xbf"\xe25Ft\xf7\xa9\xd1%\xd8 \x01Og\x02^a\xbe\n\xccS\xfb\x05oM\xf6'
        b'\xae~\xda\xe3\xfa\x83\x8fy\xaa\xdb\xf9\xd3\x96\xdf\xa1=K/ \x06)\xf5o\xaad3Y.\x98p\xbcHF\xfe\x83p\xbe \x7f\x1b\xb5\xfev\xe7\xf2\xe7\x92\xba\xb49\x9d.M\x96\x110\xc0\xd6\x8f\x97\x0c%*\x9e'
        b'[\xd3W\x0f2-\x98Wl{*\x92\x14\xef\xd8\x08\xbb\xef\tg\xd3\x90\xf4\xab$:\x07\xd7\xcd\xc3\xfe\x00F\x9c\xf8H-`yaT\x1b\x1f\x94\xd1c\xaa!\xf7\xfc\x94\xec(\x9cc\x12\xce5\xf6\xfcU-]\xff'
        b'\xec9&\xe9&>\x84+-\xa8\x11d\xd9\xb7-zv\xc1C-\xac\x01\x89\x90B\x9f!Z\xeev\xff\xe2\x07\xa1R\x95\x15\x8f\xfe}^6\xda\xed\xc6\x9e\xe7\xc9c\xbf\xd7\xe8S\xf20k\x9b\xc1\x1b\xbaj\x01+\xfe'
        b'\x89(\xa2\xa4\xcec\xda\x16\t\x9cc\\[\xc8\x8d\xc5\x0c\x1d\x94\x0c\xab\xe3\xfc\x89lP\xaf\xbf\xef\xc6Om{\xdd\xb6\x1dZ\x8b\xea+!\xd7-\xbe\x9a\xf9\xdaK\x9e\r\x1eH\x88\xa7\x875\x9f\xa9j%\xcf\xaao\xca'
        b'z\xfd\xfc\x9a>!\xf3\xb1\x0c\x7f\xde\xd3\x95\xddG\xd7\x8cL\xea\xc8\x97$\xa2kr\xef\x18\xe4\xa4\xea\xca\x88T\x8b\x04\xfb\xbd\xb7\xed\x91\xde\x7f\xb8\x08d\x89\x93\x1c\x06\x0f\xa5\xcd\x1d\xb3Z\x03\x89L\x19\xd3w\xa3e\xb2'
        b'\xe6p\x04\x80YY\xa0\x07\x8d\xe6\xf9B\x88W{\xb7l\xcf_\xeb\xa1\x83rip\x15\xefG\xfeW&s\x02\x1a\x05.\x9a\x08]\xc84\xa09\xb5\xf0SQ\xc2l\xe6=\xb5\xf2\xb6cE\x95^\xd3z\x01\xa9t\xd5'
        b'\n\x05X\x0c;<\xbd\x9a\xda\xccz9\xf5Z\x95\xd1\xd7\xdcU\xbe\xb1C\x8dc\x89*]\xa2]w=?\t\xa8%\x8e\xd5_X\xdf\xde\x08*g\x9a\xe4!2NPbz\x85k\x96\x83W%h\xe6\x14\x14c\xa0'
        b'\xdb\xc8\x1d\x03\xb8\xb5\x17\xa6$[\x01\xddQ\n\x01\x9aC\xd2\xec\x00I\xa9\xe5k\xc2\x16\xee`\xe7\xba\xcc\xff$\xe3\x15\xd92\xeb\x12\t\x81QB\xa1\xd1\xe2U|\xba\xdc\xa1\x87\x8d+\xde\xab0\x15MH\xbb\xf5\x08\x12'
        b"N2\xe0\xfb\x14'\x1f\xe22\x006u\x0b\x15:\x97\xae\xbdM\xb2\x88\xd8a\xe8\xc7u\xfd\x80H?\xea\x1aVQ?-\x04\x18rH\x16\x1e3.\n\x05\xeb>E\x00U'de\x01;n\xd7\x1c\xe4\xcf\xa1-3"
        b"F!\xe6\xa5QE\x80|So\x07d\x86\xb8\x82+ \xb1V\xbb\xddj\x80\x17\x08O\xc7\xe9\xd8:\xc6\xea\xbd\xf3`\xd3\xb0\xe8\xaf\xec\xe2\xa9\x12^\x9b+T\x8a\x0bg\x00\x1e/P\xcf\xdd\x00'w&\xa2\xd1\xac\xc8"
        b'\x00Pn\xc8mw\t\xfa\x8f\x80\xc5\xe8\x0cK\xc4\xdc\xd2\x18\xe1z\xf2\xc9\xf5\x88PI\x99\xe6\x827\xd4\xab\x05\x8fwS\x19\xb4C\xbd3\xa3\xf8(\x8f\x1dH\xcbQC\x16\x01W}\xe9\x0c\xaf`\x856\x8a\xc0\xa5\xbd'
        b'\x9d\xb31\xfe\xce\xaf\xdd\x84\x82\xed\x04\x10b-\xce\xa2\x95-\x1a/t\xc84lPK+ m\xaf;\xebr\x85\xc5J\n\x9e\x04\x83\x85\xfe\x9d\xd9\x0e\x1cgY\xd1=\xb0\x15\xc0\xb2\xc3wbM\xe9\x9cfZ\x8d\xeb'
        b'\x10<\xc0\x1bL\xc6= \xcc\xd0\xac\xf5\xfb\xeb\xc3\x06\xaa\xfe\xbf\xb28(\xad\x8f0\xa6!\x87\xb6x\xf2\xc7\x86\xc5\n\xcb\x17S\xf27\xef\xcf\x94(\x93\nWE\x93\x08\xe5I:e\xa7\\\xc2\xa9\x9b/J\\n\xc8'
        b'\x1a\xbe\xe5\xee\xed\xb8hp\xaa\xbb!\xe8-\xf4\x88\xc8\x92\x92\xf8s\xb4\xa0\x04\x18\x87B\x0e\xfc\x99f\xeaT"\x82\xe3/\xf4C-\xdf!\x91&\xd2\xf6\x1e\xed\x1e\xd9\x89\xfd\xb0W\xcd\xe3<n\xb0\x9fsk\x97uV'
        b"\xbd\xe3\x9d\xf2\xf4\x02\xe3\xfe\x15\xed\xfaAJK\xf2\xad\xad\x03p`S%\xe3\xc8tx\r'\x9f\xa9u\x90\x1e\xc1_\xaah\x9de\x9c\xdf\x01\\\x96s\xdf=RfE\xc2\xa5\xf4_\xdb\xba*\x87\xc6S\x95\x02\xf9\xb7"
        b'\xbb?\x88\xe8g\x96\xff\xa2\x9c\xb3*\xeb\x1d\xe6\xd1&o=\xed}\x1e\x16~\xd3\xdd\xcb\xb8\r\x08\xdaT\x06\xe0\x8d\xf9\x0ei\xf8~\x83\xeac\x87\xe8\xd80\xa4!\xa6\xe0\x07x\xec\xc1\xf9\xabk7\x16\xe2A\x10u\x95'
        b'\x1f\xdf0\xcc\r\x84\x06\xb9\xe9\x96\xaeH\xedi[\xf4\x10\xec\xa07\xda\x8exd9^5\x08\xb7mk\x1c\\\x13\xed\x16\xb5yL\xeb\x8fp\xef\x95\xae\n\xc6\x1b\xfe\x01\x10\xa5\xc6(\x912F\xb9\xc1h\xe8R\x91X'
        b'\xbcy\t\xdaw\xcb\x9a\x0fed\xb9\x96\xc2Jg\xb6O7}\nB;\xcb\xc7\x0f\xeb\xd5\xabh\x06S\x1c\x8f5TV8\x0fh!\x9a7\xe5\xaf\xbb\xcf\xee\xe7F>\xcd\xd0\x08\xafkwiWYS\x1fM\x06\xb0'
        b"k\x81\xa3\x87M\x0f\xf3\xac\xe6w\x84\xd4|\x17!\x98\xc9\xcb\xe5,\x0b2\x17\xf0\xbcd2ZN\xb5\x86\x15z\xfa\xf3\xf1'\xdcQ\x11\x98\xdd\xb4\x834\xdfZ-@\xe9r\x81/@)\xd2\n\xb0\xcd\xe3\xc1\x9d\x104"
        b"\x00\xb0'\xbe#p{\xd2\xb13\x8f=\xe9\xfe\x84\x1cD\xbc\x1c\xe30\x91%\xcd\x148\rT\x8dd\x88g\x8bd_\x87Tg\x94\x89&\x14\x88C\xd3y\xd7\xf0\xc4[\xa2\xd9\xb7\xeaq\xd7(\xa3\x05\xa6\x85\xbe\x02\xad"
        b"E\x16\xe3(\x95\x91\xe9\xd1,\xfb\xbb\xffR\xec.\xea\xd7\x05\xd2G7\xe1<\x8c\xe0P.#p(\r\xd0\xc8\xfe\x11{\xcbw\xadF\x9c\xf7?\x12\xe9w\\\xf6\xfeJS!@\xbdv\xea'\xdc\xaf\x13\x9f#C\x94"
        b"\xb1|BH\xde\xb1'DM\xc2Z%\x18\xb9\x11`u\x87\xea5\rf(}\xc1Q='W\xe2\xf7\x06\x15\xd41\x97\xcd\xbd\x18\xafuh\xadG\x96\xd2\x1b\xadCK\xcf\xcb\x18\xe5\x00j\x8f\xf7b+\xc9n\xc6\xbe"
        b'Oz\xa2\x84\xf5\xc9\xa9\xa2x\xcb-J\x9e\x14\xa5i\x94w.\xcf\xb6\x14e#\xbek\xb3\xb2\x95\xe07\x9e0;\xdbB\xa6\x08\xeet\x8b\xae\x08S5\to*\xaa\xfdL\x9f\x89A6\xe6F\x12\xf1\xa5$\x0e\x17\x1f'
        b'\xd2\xf6\xe9\xf4\x93\x10\x9b\x16q\x89\r)r\xfbS3\xb8QbT\xddm\xdc\x80\xeb\x01\xda\xed\xfa8\x1f\xf0\xb6\x95\xc9\xbb\xa5\xa5\x1f\x10\xe9\x1e\xb5\xfc$\xe5`\x84k\x14Ojb1\xde\xbd\xae\x8b\xbeA\xbe^93'
        b'j\xaf*\xdb\x12NL\x17\xe1\x99j=*l\xaa\xef\xecw\xd1b\xae\xdc\x06\xf1\x03\xb0\xb8\xfd\xe9\x0e\xffPr\x06\x99\xad\x87\xc2\x83\xf9\x97\x89\xde`]\r\xe2c\x8bF\xc5\xbd\x1c\x96)\xae\xeb\x87h\x06\x123_\x01'
        b'\x0b\x91\x9a\x00\x95\x15JU\xdb\xae\x98\x12\x1aFX\x01\x14\x97#\x1a\xabLa8T\x85\x93~\x8e\x10\x0e:\x16y\x0b\xa6>\xf8K]\x96.\xcc\x91\xd2\x0b\x81\x80\x1e2w\xbf\xdfGg\xeb\xedz\x91\x03\xbe$\xa8q'
        b'\xf7\x8d\x04\xe3pj6~\xb8z\xa0\xde\x1eo&\xb9 \x9b\x13F\t\x95\x8ck\xf7\n\xc5;,nP\xab>1\xd1;\xd6-\x9f\n\xbe\x9aeX5\x14f\x18X9s\xb8\xc8\xaeP\x97\x0f\xed_\xa0\x94\xa5\xde\x06'
        b'\xfcs\x84D\x83{\xc2\xfc\xb2V\x8f%\xc9T\xc2\xc26\xaaQ\x82\x03\x98\xde\x87t\xf7\x9e\x1fU&\xc8\xe8;\\\xc2R\xc3\xf0\x8aE#\x84\xe3\x7f\xb3\xc3l_\x8c]q#\xf4b\x17\xff\x97\x91\x93\x07\x94\xd7\x11\x19'
        b"\xbf2\xe5N\xcc\xeb{x\xc4\xa4.\x1b\xe6;qT\xc6\xeeGF\xaa\xf3\xaa\x87\x1a0\xfc\xa4}\xf0\x18\xd7\xd8\xac#\xa4\x96\xff\xf7G\xca\x90\xf5\xd3\x1c#'\x12\xb3\x08\x0fl\x96\xb9\x18\x15k\xf7\xf3\xc9\xf2+\x08\xdd"
        b'i\xfb:\xa8{\x17\xeb\xcf\nF;\xcf\xa3\x8a&w\x97\xf2\x9f\xa4\x05r%&\xdc\xdf\xbf\xc9Vf&\xce\x01\x14\xf6\xa0\xd6\xc0O\xd8\xdb\x912\x12{\xafGY\xdd\xf4\x87(\xf6l\x90\xd0\x89\xf5\xba\xb0\xb1Y\xf9\x90'
        b'2=\xea\xebA\x8cp\xbaf\xf2\x00y\xaf\xe6\xf4l\xbdg\xed\xe9\xc8(\x9clD\xe1\xb3eM\x7f0S\x98\x1c\x9b\xa1S>\x83*@\x98\xb1\xd2\x1f\x00\\I\x0bBi\xcf\xa4\xa8iqv;HO\x08_9\xe3'
        b'\xc6\xcd\x94\xd4 r=\xbc\xa3;\x1br\x05z3A\xf7\xc4\xc0\x87\xa5\xc4\x88&\x02\xd2:\xc88\x9eW\xff\xb9\xd0m\xf0\xa3\xd9[\x11\xab\x1f\xe9"\xbfZ;F\xf9\x84\x9e\x99PxW\xa2\x9f\xff2\x9c\xed\x1e\xbe\xdd'
        b'\x9b\xef\xff\xcd\x05\xaf\xc1\xe9\x1b\xbaz\xd2K\x16\xd6\x15)\xa9;{\x80\x0f\r\x08\x85\xfd\xe6\xdb\x00\xb2\x07\xb1\xe7\xa7Q\xac\xcb\xc2D\xdbYA\xf56\x10+\x16\xd1\xba\xb1\xf8>\xf7\x192\x94\xac\rah[\x91\xd2U'
        b']G\x92\x83\x8c,>\xb8\xa6\xcfj\x1f\xbbH@\x1eJM\xe7d\x14\xe7\x16\xd4or\xa2\xe0\\\x07\xcb\x85\x12T\x91\xce6L\xcc\xfc\xe02\xb1\x90\x01\x9e\xda<\x9e\x8f\xf2zO\x8f}\x95\x972\xb9\xb1\xe6C\xc0\x8d'
        b'A\x83-\x94\xfd\x8f\xea\x02\xed\x1b\x80\xf2y\x02mUv\x99\x03\xfev\xf3\xbe\xff_\xb7\x0e\xadt+\xe9\x8e\x19V\xa5D\xe7d\xa8\x0e\xe3b\xb8\xa4\xd0\x12\xed\xbaO\x8f%\xc0\t\x88-\x89\x9bS\xee\xc6\xcb5\xdd\xbf'
        b'(\xf8+\r\xe8\x9d\xe5Q\xb3\xbe\xae\xbf\x06P\xc7*\x9c}\x80\x8c\xd0\xc2l\xf1\xcd\xac\x1ag\x9c\xe0<\x0f\x1f\x89\x05\xc3\xc0`\xa1\xda?\xce\x9b\xa5\x86ay\xa3\x1f\x90S[\x0fZ\x12\xd1\x8f\x18\xf3\x8c\r\x1f\x99\xc8'
        b'\x18\x14U\xafF\x83\xdfVK\xf7c\x15z4\x96"\xc8]\xf6\xf8M)\xa6\xfb\xf8\xc0\xbcW\x9ai\xbc\x9e\x9e\x1d[\xee\x87R\x1f\xbe\xdc_\x87a7\x13\xca\x98m\xd2\x11\xd9\x14\xbc\xf9uf\xf3\xed\x0e\x16\x97\xcb-'
        b"Wj\x0cY\t]v*`@\xd3\xeb\xfc\xa8\xff[\x08G\xb5'\x13\xa9\x11o\xf0u \xe7\xf7\xef\xed\x11\xf0\x8e\xf5\xb8zCU\xcb\xb4\xc7\xad+$O\xe3\xb1\xf0(u\x8a\x0e\x8c@\xa9.R\xf4\x89qy\xb7\xee"
        b"'\xb2(IC\x17y\xc1\xb8\x9e\x9b\x9b\x94%\x94\x7f\xa7\xab\x02p\xb2s\xb1\\w\x97\xc2\xc6.,\xb5\x81N\\\t\x97$\xbe\x85\xe3\xb1\x7f\x01\x8e\x00\x07F\n\xff\xa9a\xf2\xcf\x86\x0e\xfb?\xeb\x18\xe2\xf6KC+"
        b"\x0b\xfc\xe6\x13y0\x937\xede\xc5\xfaU\x1f\xa9\xd4\x80~\x13\xff\xa4\xd8\xfc\x05+o\xf5\xef\xddN\x929QO\xfe\x1b\xf3\xdd\x9f\xa2\xa9ldL'*\x97\xf0\xd4\xa2\xad\xad\xad\x92\xf1\xf6\x8dn\x0e\xe1\xcb\xd6b\xe4"
        b'I\xd3\xd2\r\xb5\x1b`\xf1K\xb0\xcb;@\x906\xebo\x18\xc3\xfe0^-y\xd0\x88\x06\x80g2\xea\x1e\xd0\x89\xe9\xc9e]\x16\xb5\x81\x80\xcb%q\xe6!\xf1\x0e\x85\nl\xb9\xf5\xfado\xb5&\xe0\xd1?\xfc\x08'
        b'4=q9\xee\x1f\xb8\x0f\x0b\x93\xa2;\xc8s&J\x80jl\xfc\xb1`<\x1f\x94y\xa4\xdb\x9c\xfdU\xf9W\xf5\xb4A\xcd\x8b\xf4~\xb4D\x11\xae\xbe\x9ft#\x9d\xea>D\x14E\x0b\xeeS7C9r\x112\xe9'
        b'\xc0\xe8\xef\xa6\x15\xbe\xe7c\xc5v\x1c5K\xaef\x85\xbaI5a\x88\xf2\xdd5.\xe7\x1d\x07\x02\xb5\x84\x92\xe6\xa3\xfa\x05\xfcl\xc1]\x95~\xa9!w)\xd6X_3|\xfe\xd7\xf5H--\xc5\xa97S\xbdY\x06'
        b'\xff\xce\x99\taY\x10\x02\x80\x1b\xdf)\x8c\xfc\x83\xcc\xba\xbdA\xd0\x14\xa1*\x00\xc2\xbdm,\x9e\xf1!\xa5\xd1U$,\xa9)\n\x88\x8b)\x9c\xc7\xecR\x97\x8d\xc0\x96\xa3?4}\xb5\x8d\xc3O \x15\x81\x83\xbf\xad'
        b'\x01\t\xfcU\x88n\xd7)`.1\xf3_\xc9\x1f\xf0\x83\xf3\x85\x08Z\x9eG\xc9\x81Y\xdc\xb8\xb3\xee\xfc3\xb3*\xb2\x9a\xba\xde\x06\xaec\x19!\xc4\x13J\xd1\xd4\xd7\xc1\xf7\xc3t\x8e\xb4\xc2 cOK2\xfe\xbc\xec'
        b"\x94\xf2\xdb\xeaZ\xf7\xc0\x83'\x9fq\xb3\xae\xd9\x91\x1b\xb1\x05\xfe\xbb\x02\xc1s\xa7W\xc5T{[iN\x9c\xfd\xaf'\xed\xc4\xfc4\x9e\x99\x0b\xf4\xdd\xb0\x15\xa9\xee\x07\x95\xf4\xea\xf3\x7f\x17\xaa\x95>\xa2\xc4Kk\xfe\x8e"
        b't\x9bD*\xff\xc0OL6\x9c^\x9a)IP~\x01|DU\x99\xf2\xb3\xda\xe0\xaf\xf3\xe1\xd8xa{M\x02\xc2\xb9\x0c\xcf\x97\xb8D\x117&\xf1\xf6\xaa(=\xbd\xe0W\xa6V;\x07\x95\xf65\xd2\xc1#\x88\x1b'
        b'\xf0\x1a\x88w\xa7\x0f\xc0\x1aR \xc5\x7f\x9d\xc0\x8a\x14\x98\x85\x05\xd3D3\x08^\x1a\r\x19\x96\x96\xec\xad\x06\xc1\xed\xa7L\'"*\x14\x85\xb5\xcf,\xa4\xc3\xa1\xdb\x0c\xc7\xda\t\xa6y\n\x8a\xea\xc8\xca\xf5\x10\x8e\x0c\xcd'
        b'\xcc\xd7\xb9\\+iu\x11\xfa\xa3\xe6a\xa5rJ\xf1\xabS`]W\xcf<9U]EvIXu%\\qp\x98\xe9\x08\xc6\x1e\xa6Jh\xc7v\xba\x8fCWb\xc1\r\x87\n\xe5\x13v\x92j\x1d\x06\xeb"d'
        b'&\xa5\xf9&\x9a\xe0\xdd\x12\x16\x9e\x8d}\xf229\x82{9\x0c|\xb3M\x1d\x0e\xe4\x02\xd8\x9dG\xad\xbe\xb6q\xc9\xda\xf3V\x86m_\x88\x8b\x91\xcf\xeb\x0c<~\x02/\xa2z\x85em\x00mW\xbd\x8b\x9d\xe9\x01\x00'
        b'\x00\x00N)\x04Z\x0b__pyarmor__\xda\x0cRuntimeError\xda\x08__name__\xda\x08__file__\xa9\x00r\x05\x00\x00\x00r\x05\x00\x00\x00'
        b'\xfa\x16<frozen fintech.swift>\xda\x08<module>\x01\x00\x00\x00s\x06\x00\x00\x00\n\x00\x0e\x01\x12\x01'
    ))
